@@ -51,7 +51,7 @@ class CartoDBBase(object):
     """ basic client to access cartodb api """
     MAX_GET_QUERY_LEN = 2048
 
-    def __init__(self, cartodb_domain, host='cartodb.com', protocol='https', api_version='v1'):
+    def __init__(self, cartodb_domain, host='cartodb.com', protocol='https', api_version='v2'):
         self.resource_url = RESOURCE_URL % {'user': cartodb_domain, 'domain': host, 'protocol': protocol, 'api_version': api_version}
 
     def req(self, url, http_method="GET", http_headers=None, body=''):
@@ -60,11 +60,16 @@ class CartoDBBase(object):
         """
         raise NotImplementedError('req method must be implemented')
 
-    def sql(self, sql, parse_json=True, do_post=True):
+    def sql(self, sql, parse_json=True, do_post=True, format=None):
         """ executes sql in cartodb server
             set parse_json to False if you want raw reponse
         """
-        p = urllib.urlencode({'q': sql})
+        params = {'q': sql}
+        if format:
+            params['format'] = format
+            if format not in ['json', 'geojson']:
+                parse_json = False
+        p = urllib.urlencode(params)
         url = self.resource_url
         # depending on query size do a POST or GET
         if len(sql) < self.MAX_GET_QUERY_LEN and not do_post:
